import { Redis } from '@upstash/redis';
export declare const LogProvider: {
    readonly CONSOLE: "CONSOLE";
    readonly FILE: "FILE";
    readonly UPSTASH: "UPSTASH";
};
export type LogProvider = typeof LogProvider[keyof typeof LogProvider];
export declare enum LogLevel {
    DEBUG = 0,
    INFO = 1,
    WARN = 2,
    ERROR = 3
}
interface BaseLogMessage {
    message: string;
    destinationPath: string;
}
export interface Logger<T extends BaseLogMessage = BaseLogMessage> {
    debug(message: T | string, ...args: any[]): void;
    info(message: T | string, ...args: any[]): void;
    warn(message: T | string, ...args: any[]): void;
    error(message: T | string, ...args: any[]): void;
}
interface ConsoleLoggerOptions {
    level?: LogLevel;
}
interface FileLoggerOptions {
    dirPath: string;
    level?: LogLevel;
}
interface UpstashRedisLoggerOptions {
    redisClient: Redis;
    key: string;
    level?: LogLevel;
}
interface LoggerRegistry<T extends BaseLogMessage = BaseLogMessage> {
    [LogProvider.CONSOLE]: {
        logger: ConsoleLogger<T>;
        options: ConsoleLoggerOptions;
    };
    [LogProvider.FILE]: {
        logger: FileLogger<T>;
        options: FileLoggerOptions;
    };
    [LogProvider.UPSTASH]: {
        logger: UpstashRedisLogger<T>;
        options: UpstashRedisLoggerOptions;
    };
}
declare abstract class BaseLogger<T extends BaseLogMessage = BaseLogMessage> implements Logger<T> {
    protected level: LogLevel;
    constructor(level?: LogLevel);
    abstract log(level: LogLevel, message: T | string, ...args: any[]): void;
    debug(message: T | string, ...args: any[]): void;
    info(message: T | string, ...args: any[]): void;
    warn(message: T | string, ...args: any[]): void;
    error(message: T | string, ...args: any[]): void;
    protected formatMessage(message: T | string): string;
}
/**
 * Logs to the console
 */
declare class ConsoleLogger<T extends BaseLogMessage = BaseLogMessage> extends BaseLogger<T> {
    constructor({ level }: {
        level?: LogLevel;
    });
    log(level: LogLevel, message: T | string, ...args: any[]): void;
}
/**
 * Logs to a file
 */
declare class FileLogger<T extends BaseLogMessage = BaseLogMessage> extends BaseLogger<T> {
    #private;
    constructor({ dirPath, level }: {
        dirPath: string;
        level?: LogLevel;
    });
    log(level: LogLevel, message: T): void;
}
/**
 * Logs to Upstash Redis
 */
declare class UpstashRedisLogger<T extends BaseLogMessage = BaseLogMessage> extends BaseLogger<T> {
    #private;
    constructor({ redisClient, level, key }: {
        redisClient: Redis;
        level?: LogLevel;
        key: string;
    });
    log(level: LogLevel, message: T): void;
    getLogs(key: string): Promise<string[]>;
}
export declare function createLogger<T extends BaseLogMessage = BaseLogMessage, K extends keyof LoggerRegistry<T> = keyof LoggerRegistry<T>>({ type, options }: {
    type: K;
    options?: LoggerRegistry[K]['options'];
}): LoggerRegistry<T>[K]['logger'];
export {};
//# sourceMappingURL=logger.d.ts.map